==> ipycollections-0.3.0.tar.gz: ipycollections-0.3.0/README.md <==
# ipycollections

[![Github Actions Status](git+https://github.com/dataflownb/ipycollections-extension.git/workflows/Build/badge.svg)](git+https://github.com/dataflownb/ipycollections-extension.git/actions/workflows/build.yml)
A JupyterLab extension that provides a more interactive format for collections

## Requirements

- JupyterLab >= 3.0

## Install

To install the extension, execute:

```bash
pip install ipycollections
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall ipycollections
```

## Usage

In a JupyterLab notebook, use the following line to enable the extension

```
%load_ext ipycollections
``` 

If you would like the extension to be enabled by default, edit your 
[configuration file](https://ipython.readthedocs.io/en/stable/development/config.html) 
(often `~/.ipython/profile_default/ipython_config.py`) to include `ipycollections` as an extension:

```
c.InteractiveShellApp.extensions = [
    'ipycollections',
    # ...
]
```

If you wish to disable the extension, use:

```
%unload_ext ipycollecitons
```

## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the ipycollections directory
# Install package in development mode
pip install -e "."
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Rebuild extension Typescript source after making changes
jlpm build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
pip uninstall ipycollections
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `@dfnotebook/ipycollections-extension` within that folder.

### Testing the extension

#### Frontend tests

This extension is using [Jest](https://jestjs.io/) for JavaScript code testing.

To execute them, execute:

```sh
jlpm
jlpm test
```

#### Integration tests

This extension uses [Playwright](https://playwright.dev/docs/intro/) for the integration tests (aka user level tests).
More precisely, the JupyterLab helper [Galata](https://github.com/jupyterlab/jupyterlab/tree/master/galata) is used to handle testing the extension in JupyterLab.

More information are provided within the [ui-tests](./ui-tests/README.md) README.

### Packaging the extension

See [RELEASE](RELEASE.md)

==> ipycollections-0.4.0.tar.gz: ipycollections-0.4.0/README.md <==
# ipycollections

[![Github Actions Status](https://github.com/dataflownb/ipycollections-extension.git/workflows/Build/badge.svg)](https://github.com/dataflownb/ipycollections-extension.git/actions/workflows/build.yml)
A JupyterLab extension that provides a more interactive format for collections

## Requirements

- JupyterLab >= 4.0.0

## Install

To install the extension, execute:

```bash
pip install ipycollections
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall ipycollections
```

## Usage

In a JupyterLab notebook, use the following line to enable the extension

```
%load_ext ipycollections
``` 

If you would like the extension to be enabled by default, edit your 
[configuration file](https://ipython.readthedocs.io/en/stable/development/config.html) 
(often `~/.ipython/profile_default/ipython_config.py`) to include `ipycollections` as an extension:

```
c.InteractiveShellApp.extensions = [
    'ipycollections',
    # ...
]
```

If you wish to disable the extension, use:

```
%unload_ext ipycollecitons
```

## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the ipycollections directory
# Install package in development mode
pip install -e "."
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Rebuild extension Typescript source after making changes
jlpm build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
pip uninstall ipycollections
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `@dfnotebook/ipycollections-extension` within that folder.

### Testing the extension

#### Frontend tests

This extension is using [Jest](https://jestjs.io/) for JavaScript code testing.

To execute them, execute:

```sh
jlpm
jlpm test
```

#### Integration tests

This extension uses [Playwright](https://playwright.dev/docs/intro) for the integration tests (aka user level tests).
More precisely, the JupyterLab helper [Galata](https://github.com/jupyterlab/jupyterlab/tree/master/galata) is used to handle testing the extension in JupyterLab.

More information are provided within the [ui-tests](./ui-tests/README.md) README.

### Packaging the extension

See [RELEASE](RELEASE.md)
